From 693ece719056ef2b8de118df9bfab799ba56b547 Mon Sep 17 00:00:00 2001
From: Chen Qun <kuhn.chenqun@huawei.com>
Date: Mon, 30 Mar 2020 21:10:12 +0800
Subject: [PATCH 24/28] qcontainer: change EFI pflash path for different OS in
 aarch64

For most OS, it is the default path of EDK2
(default path for aarch64:
/usr/share/edk2/aarch64/QEMU_EFI-pflash.raw
/usr/share/edk2/aarch64/QEMU_VARS.fd)

Signed-off-by: Chen Qun <kuhn.chenqun@huawei.com>
---
 virttest/qemu_devices/qcontainer.py | 26 ++++++++++++++++++++------
 1 file changed, 20 insertions(+), 6 deletions(-)

diff --git a/virttest/qemu_devices/qcontainer.py b/virttest/qemu_devices/qcontainer.py
index 497e493b..f1152f7a 100644
--- a/virttest/qemu_devices/qcontainer.py
+++ b/virttest/qemu_devices/qcontainer.py
@@ -1153,9 +1153,16 @@ class DevContainer(object):
                                       "AAVMF variables file.")
             logging.warn('Support for aarch64 is highly experimental!')
             devices = []
+            if os.path.exists("/usr/share/edk2/aarch64/QEMU_EFI-pflash.raw"):
+                aavmf_code_file = "/usr/share/edk2/aarch64/QEMU_EFI-pflash.raw"
+                aavmf_vars_file = "/usr/share/edk2/aarch64/QEMU_EFI-pflash.raw"
+            else:
+                aavmf_code_file = "/usr/share/AAVMF/AAVMF_CODE.fd"
+                aavmf_vars_file = "/usr/share/AAVMF/AAVMF_VARS.fd"
+
             # EFI pflash
-            aavmf_code = ("-drive file=/usr/share/AAVMF/AAVMF_CODE.fd,"
-                          "if=pflash,format=raw,unit=0,readonly=on")
+            aavmf_code = ("-drive file=" + aavmf_code_file +
+                          ",if=pflash,format=raw,unit=0,readonly=on")
             devices.append(qdevices.QStringDevice('AAVMF_CODE',
                                                   cmdline=aavmf_code))
             aavmf_vars = get_aavmf_vars(params)
@@ -1168,7 +1175,7 @@ class DevContainer(object):
                                  " only happen when you install the machine as"
                                  " there is no default boot in EFI!)",
                                  aavmf_vars)
-                shutil.copy2('/usr/share/AAVMF/AAVMF_VARS.fd', aavmf_vars)
+                shutil.copy2(aavmf_vars_file, aavmf_vars)
             aavmf_vars = ("-drive file=%s,if=pflash,format=raw,unit=1"
                           % aavmf_vars)
             devices.append(qdevices.QStringDevice('AAVMF_VARS',
@@ -1207,8 +1214,15 @@ class DevContainer(object):
             logging.warn('Support for aarch64 is highly experimental!')
             devices = []
             # EFI pflash
-            aavmf_code = ("-drive file=/usr/share/AAVMF/AAVMF_CODE.fd,"
-                          "if=pflash,format=raw,unit=0,readonly=on")
+            if os.path.exists("/usr/share/edk2/aarch64/QEMU_EFI-pflash.raw"):
+                aavmf_code_file = "/usr/share/edk2/aarch64/QEMU_EFI-pflash.raw"
+                aavmf_vars_file = "/usr/share/edk2/aarch64/QEMU_EFI-pflash.raw"
+            else:
+                aavmf_code_file = "/usr/share/AAVMF/AAVMF_CODE.fd"
+                aavmf_vars_file = "/usr/share/AAVMF/AAVMF_VARS.fd"
+
+            aavmf_code = ("-drive file=" + aavmf_code_file +
+                          ",if=pflash,format=raw,unit=0,readonly=on")
             devices.append(qdevices.QStringDevice('AAVMF_CODE',
                                                   cmdline=aavmf_code))
             aavmf_vars = get_aavmf_vars(params)
@@ -1221,7 +1235,7 @@ class DevContainer(object):
                                  " only happen when you install the machine as"
                                  " there is no default boot in EFI!)",
                                  aavmf_vars)
-                shutil.copy2('/usr/share/AAVMF/AAVMF_VARS.fd', aavmf_vars)
+                shutil.copy2(aavmf_vars_file, aavmf_vars)
             aavmf_vars = ("-drive file=%s,if=pflash,format=raw,unit=1"
                           % aavmf_vars)
             devices.append(qdevices.QStringDevice('AAVMF_VARS',
-- 
2.23.0

